mysql.exceptions.internal

Package mysql :: Package exceptions :: Module internal |
[hide private]
[frames] | no frames]

# Source Code for Module mysql.exceptions.internal

     1  # $Header: /home/cvs2/mysql/mysql/exceptions/internal.py,v 1.2 2006/08/26 20:19:52 ehuss Exp $
     2  # Copyright (c) 2006, Eric Huss
     3  # All rights reserved.
     4  #
     5  # Redistribution and use in source and binary forms, with or without
     6  # modification, are permitted provided that the following conditions are met:
     7  #
     8  # 1. Redistributions of source code must retain the above copyright notice,
     9  #    this list of conditions and the following disclaimer.
    10  # 2. Redistributions in binary form must reproduce the above copyright notice,
    11  #    this list of conditions and the following disclaimer in the documentation
    12  #    and/or other materials provided with the distribution.
    13  # 3. Neither the name of Eric Huss nor the names of any contributors may be
    14  #    used to endorse or promote products derived from this software without
    15  #    specific prior written permission.
    16  #
    17  # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
    18  # AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
    19  # IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
    20  # ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
    21  # LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
    22  # CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
    23  # SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
    24  # INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
    25  # CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
    26  # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
    27  # POSSIBILITY OF SUCH DAMAGE.
    28
    29  """Internal errors from the MySQL Python code.
    30  """
    31
    32  __version__ = '$Revision: 1.2 $'
    33
    34  from mysql.exceptions.base import Error
    35
    36 -class Not_Connected_Error(Error):
    37
    38      """Tried to run a command when no connection is established."""
    39
    40 -class Connected_Error(Error):
    41
    42      """Attempted to use a command that cannot be used while connected."""
    43
    44 -class Data_Truncated(Error):
    45
    46      """Data was truncated in the last fetch."""
    47
    48 -class Affected_Rows_Unavailable(Error):
    49
    50      """The number of affected rows is not available.
    51
    52      This can be because the query returned an error, or ``store_result`` was
    53      not set on a SELECT query.
    54      """
    55
    56 -class Result_Unbuffered_Error(Error):
    57
    58      """Attempted to call a method that requires the results to be buffered
    59      (stored) locally.
    60      """
    61
    62 -class Result_Closed_Error(Error):
    63
    64      """Attempted to use a result object that has been closed."""
    65
    66 -class No_Statement_Info_Error(Error):
    67
    68      """Information is not available for the last statement when using the
    69      `mysql.connection.Connection.last_statement_info` method.
    70      """
    71
    72 -class No_Insert_ID_Error(Error):
    73
    74      """The last insert ID is not available when calling the
    75      `mysql.connection.Connection.last_insert_id` method.
    76      """
    77
    78 -class No_More_Results(Error):
    79
    80      """No more results are available in the `mysql.connection.Connection.next_result` method."""
    81
    82 -class No_More_Rows(Error):
    83
    84      """The last row was reached in the `mysql.result.Result.fetch_row` method."""
    85
    86 -class Statement_Closed_Error(Error):
    87
    88      """Attempted to use a statement object that has been closed."""
    89
    90 -class Connected_Error(Error):
    91
    92      """Attempted to use a command that cannot be used while connected."""
    93